JmolHelp
Author: J. Gutow
Description: Brief Jmol instructions for SAGE math

### Brief Help for the Jmol 3-D viewer

Reorient View
  To reorient the view place cursor over the image, hold down the mouse button and drag.
Zoom View
  To zoom place the cursor over the image hold down the shift key and the mouse button while dragging down to zoom in or up to zoom out.
Change Applet Size
  Select the desired size from the pop-up menu in the "Display" tab available in the "Advanced Controls" or click on the "Open in own window" button. The resulting window's size can be adjusted.
Adjust Colors and Mesh
  Select desired colors and translucency using the menus and checkboxes in the "Colors & Mesh" tab available in the "Advanced Controls".
Save as Static Image
  Click on the "Get Static Image to Save" button in the "Display" tab available in the "Advanced Controls".
Download to open in Jmol Application
  Click on the "Download View" button in the "Display" tab available in the "Advanced Controls". The file you download can be opened using the Jmol application. Using the application the view can be further adjusted and web pages with the live view embedded can be created (see below).
Start/Stop Spinning
  Use the "Spin" checkbox in the "Display" tab available in the "Advanced Controls".
High/Low Quality Display
  Use the "High Quality" checkbox in the "Display" tab available in the "Advanced Controls". Note memory requirements are significantly more for the better display. This can slow the applets response and sometimes causes blank displays.
Embedding the live image in another web page, adding annotation and advanced control of view

1. Download the view to your computer using the download button in the Display tab. You can then open the file in the Jmol application available from the Jmol web site.
2. Simple examples of adding annotation are provided in the Export-to-Web tutorial, which also describes how to use the downloaded document to embed the live image in an arbitrary web page.
3. More detailed information on changing the way Jmol displays things using Jmol commands is available in the Jmol scripting documentation, the Jmol web site and the Jmol wiki.
4. It is also possible to use Jmol commands to adjust the display within Sage. To do this right-click (control-click) in the applet window to get the applet pop-up menu. In the advanced submenu select "Console". You can type Jmol script commands into the console.

By Jonathan Gutow
June 2011